# UTF-8 Encoded file without BOM

module MaterialList
  
  def self.list_materials
    materials = self.materials_hash
    puts self.hash_to_json( materials, true ) # DEBUG
    json = self.hash_to_json( materials )
    wd = UI::WebDialog.new( 'Materials' )
    wd.add_action_callback( 'ready' ) { |window, params|
      js = "add_materials( #{json} );"
      window.execute_script( js );
    }
    wd.set_html( self.html )
    wd.show
  end

  def self.materials_hash
    materials = {}
    for material in Sketchup.active_model.materials
      materials[ material.name ] = material.display_name
    end
    materials
  end
  
  # Very simplified method just for this example's purpose.
  def self.hash_to_json( hash, pretty_print = false )
    if pretty_print
      nl  = "\n"
      tab = "  "
    else
      nl  = ""
      tab = ""
    end
    
    json = "{#{nl}"
    items = []
    for key, value in hash
      items << "#{tab}#{key.inspect}: #{value.inspect}"
    end
    json << items.join(",#{nl}")
    json << "#{nl}}#{nl}"
    json
  end
  
  def self.html
    output = <<EOT
<!DOCTYPE html>
<html>
<head>
  <meta http-equiv="content-type" content="text/html; charset=utf-8" />
  <script src="https://ajax.googleapis.com/ajax/libs/jquery/1.8.3/jquery.min.js"></script>
  <script>
    $( document ).ready( function() {
      window.location.href = 'skp:ready';
    });
    
    var materials_map = [];
    
    function add_materials( materials )
    {
      var stack = sort_by_value( materials );
      
      var $list = $('#lstMaterials');
      for ( var i = 0; i < stack.length; i++ )
      {
        name = stack[i][0];
        display_name = stack[i][1];;
        
        materials_map[i] = name;
        
        $option = $('<option/>');
        $option.text( display_name );
        $option.val( i );
        $list.append( $option );
      }
      $list.on( 'change', function() {
        var $option = $(this);
        var index = $option.val();
        alert( materials_map[index] );
      });
    }
    
    // http://stackoverflow.com/a/1359895/486990
    function sort_by_value( json )
    {
      var stack = [];
      for ( var key in json )
      {
        if( json.hasOwnProperty(key) )
          stack.push( [ key, json[key] ] );
      }
      stack.sort( function(a,b){ return a[1] > b[1] ? 1 : -1; } );
      return stack;
    }
  </script>
  <style>
    html {
      font-family: sans-serif;
    }
    #lstMaterials {
      width: 100%;
    }
  </style>
</head>
<body>
  
  Testing UTF-8 Characters: Æ Ø Å
  
  <hr>
  
  <select size="20" id="lstMaterials">
  <select>
  
</body>
</html>
    
EOT
    output
  end

end # module

# MaterialList.list_materials # DEBUG